summaryrefslogtreecommitdiffstats
path: root/kreversi/qreversigame.h
diff options
context:
space:
mode:
Diffstat (limited to 'kreversi/qreversigame.h')
-rw-r--r--kreversi/qreversigame.h13
1 files changed, 7 insertions, 6 deletions
diff --git a/kreversi/qreversigame.h b/kreversi/qreversigame.h
index b4dcb19b..875d2c07 100644
--- a/kreversi/qreversigame.h
+++ b/kreversi/qreversigame.h
@@ -36,8 +36,8 @@
*******************************************************************
*/
-#ifndef __QREVERSIGAME__H__
-#define __QREVERSIGAME__H__
+#ifndef __TQREVERSIGAME__H__
+#define __TQREVERSIGAME__H__
#include <tqwidget.h>
#include <tqpixmap.h>
@@ -52,7 +52,7 @@ class KConfig;
// The main document class in the reversi program. The thing that
// makes this a QReversiGame instead of just a ReversiGame is that it
// emits signals that can be used to update a view.
//
// Signals:
@@ -62,12 +62,13 @@ class KConfig;
// gameOver()
//
-class QReversiGame : public TQObject, public Game {
+class TQReversiGame : public TQObject, public Game {
Q_OBJECT
+ TQ_OBJECT
public:
- QReversiGame(TQObject *parent = 0);
- ~QReversiGame();
+ TQReversiGame(TQObject *tqparent = 0);
+ ~TQReversiGame();
// Methods dealing with the game
void newGame();
@@ -52,7 +52,7 @@ class KConfig;
// The main document class in the reversi program. The thing that
-// makes this a QReversiGame instead of just a ReversiGame is that it
+// makes this a TQReversiGame instead of just a ReversiGame is that it
// emits signals that can be used to update a view.
//